summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/svl/itemset.hxx1
-rw-r--r--include/svl/poolitem.hxx1
-rw-r--r--sc/Library_sc.mk1
-rw-r--r--sc/inc/attarray.hxx4
-rw-r--r--sc/inc/column.hxx6
-rw-r--r--sc/inc/poolcach.hxx (renamed from include/svl/poolcach.hxx)24
-rw-r--r--sc/inc/table.hxx2
-rw-r--r--sc/source/core/data/attarray.cxx20
-rw-r--r--sc/source/core/data/column.cxx20
-rw-r--r--sc/source/core/data/document.cxx4
-rw-r--r--sc/source/core/data/poolcach.cxx (renamed from svl/source/items/poolcach.cxx)17
-rw-r--r--sc/source/core/data/table2.cxx6
-rw-r--r--solenv/clang-format/excludelist4
-rw-r--r--svl/Library_svl.mk1
14 files changed, 53 insertions, 58 deletions
diff --git a/include/svl/itemset.hxx b/include/svl/itemset.hxx
index 60f028aeac39..599afc7ab5bd 100644
--- a/include/svl/itemset.hxx
+++ b/include/svl/itemset.hxx
@@ -101,7 +101,6 @@ protected:
return m_ppItems[idx];
}
-friend class SfxItemPoolCache;
friend class SfxAllItemSet;
private:
diff --git a/include/svl/poolitem.hxx b/include/svl/poolitem.hxx
index d5499351bd1e..38e6e44edc93 100644
--- a/include/svl/poolitem.hxx
+++ b/include/svl/poolitem.hxx
@@ -111,7 +111,6 @@ class SVL_DLLPUBLIC SfxPoolItem
{
friend class SfxItemPool;
friend class SfxItemDisruptor_Impl;
- friend class SfxItemPoolCache;
friend class SfxItemSet;
// allow ItemSetTooling to access
diff --git a/sc/Library_sc.mk b/sc/Library_sc.mk
index ff53d9b63ef1..d355dc0782dc 100644
--- a/sc/Library_sc.mk
+++ b/sc/Library_sc.mk
@@ -178,6 +178,7 @@ $(eval $(call gb_Library_add_exception_objects,sc,\
sc/source/core/data/pagepar \
sc/source/core/data/patattr \
sc/source/core/data/pivot2 \
+ sc/source/core/data/poolcach \
sc/source/core/data/poolhelp \
sc/source/core/data/postit \
sc/source/core/data/queryevaluator \
diff --git a/sc/inc/attarray.hxx b/sc/inc/attarray.hxx
index 0d2457c0db25..a7e1c08a9f49 100644
--- a/sc/inc/attarray.hxx
+++ b/sc/inc/attarray.hxx
@@ -36,7 +36,7 @@ class ScMarkArray;
class ScStyleSheet;
class ScFlatBoolRowSegments;
-class SfxItemPoolCache;
+class ScItemPoolCache;
class SfxStyleSheetBase;
class SvxBoxItem;
class SvxBoxInfoItem;
@@ -155,7 +155,7 @@ public:
bool bPutToPool = false, ScEditDataArray* pDataArray = nullptr)
{ SetPatternAreaImpl(nStartRow, nEndRow, pPattern, bPutToPool, pDataArray, /*bPassingOwnership*/false); }
void ApplyStyleArea( SCROW nStartRow, SCROW nEndRow, const ScStyleSheet& rStyle );
- void ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCache* pCache,
+ void ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, ScItemPoolCache* pCache,
ScEditDataArray* pDataArray = nullptr, bool* const pIsChanged = nullptr );
void SetAttrEntries(std::vector<ScAttrEntry> && vNewData);
void ApplyLineStyleArea( SCROW nStartRow, SCROW nEndRow,
diff --git a/sc/inc/column.hxx b/sc/inc/column.hxx
index 27db1391472e..914199be25b5 100644
--- a/sc/inc/column.hxx
+++ b/sc/inc/column.hxx
@@ -71,7 +71,7 @@ class Sparkline;
class Fraction;
class OutputDevice;
-class SfxItemPoolCache;
+class ScItemPoolCache;
class SvtListener;
class SfxPoolItem;
class SfxStyleSheetBase;
@@ -144,7 +144,7 @@ public:
const ScPatternAttr* GetPattern( SCROW nRow ) const;
const ScPatternAttr* GetMostUsedPattern( SCROW nStartRow, SCROW nEndRow ) const;
- SCROW ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray, bool* const pIsChanged,
+ SCROW ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray, bool* const pIsChanged,
SCCOL nCol );
void ApplyPatternArea( SCROW nStartRow, SCROW nEndRow, const ScPatternAttr& rPatAttr,
ScEditDataArray* pDataArray = nullptr,
@@ -575,7 +575,7 @@ public:
void RemoveProtected( SCROW nStartRow, SCROW nEndRow );
- SCROW ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray, bool* const pIsChanged );
+ SCROW ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray, bool* const pIsChanged );
void DeleteSelection( InsertDeleteFlags nDelFlag, const ScMarkData& rMark, bool bBroadcast );
void ClearSelectionItems( const sal_uInt16* pWhich, const ScMarkData& rMark );
diff --git a/include/svl/poolcach.hxx b/sc/inc/poolcach.hxx
index fe06ce416415..6e3c3deda916 100644
--- a/include/svl/poolcach.hxx
+++ b/sc/inc/poolcach.hxx
@@ -16,23 +16,22 @@
* except in compliance with the License. You may obtain a copy of
* the License at http://www.apache.org/licenses/LICENSE-2.0 .
*/
-#ifndef INCLUDED_SVL_POOLCACH_HXX
-#define INCLUDED_SVL_POOLCACH_HXX
+#pragma once
-#include <svl/svldllapi.h>
+#include "scdllapi.h"
#include <vector>
class SfxItemPool;
class SfxItemSet;
class SfxPoolItem;
-class SfxSetItem;
+class ScPatternAttr;
-class SVL_DLLPUBLIC SfxItemPoolCache
+class ScItemPoolCache
{
struct SfxItemModifyImpl
{
- const SfxSetItem *pOrigItem;
- SfxSetItem *pPoolItem;
+ const ScPatternAttr *pOrigItem;
+ ScPatternAttr *pPoolItem;
};
SfxItemPool *pPool;
@@ -42,16 +41,13 @@ class SVL_DLLPUBLIC SfxItemPoolCache
const SfxPoolItem *pItemToPut;
public:
- SfxItemPoolCache( SfxItemPool *pPool,
+ ScItemPoolCache( SfxItemPool *pPool,
const SfxPoolItem *pPutItem );
- SfxItemPoolCache( SfxItemPool *pPool,
+ ScItemPoolCache( SfxItemPool *pPool,
const SfxItemSet *pPutSet );
- ~SfxItemPoolCache();
+ ~ScItemPoolCache();
- const SfxSetItem& ApplyTo( const SfxSetItem& rSetItem );
+ const ScPatternAttr& ApplyTo( const ScPatternAttr& rSetItem );
};
-
-#endif
-
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sc/inc/table.hxx b/sc/inc/table.hxx
index e81639ff6a53..3bf61e701c16 100644
--- a/sc/inc/table.hxx
+++ b/sc/inc/table.hxx
@@ -821,7 +821,7 @@ public:
bool ApplyFlags( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow, ScMF nFlags );
bool RemoveFlags( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow, ScMF nFlags );
- void ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray = nullptr, bool* const pIsChanged = nullptr );
+ void ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray = nullptr, bool* const pIsChanged = nullptr );
void DeleteSelection( InsertDeleteFlags nDelFlag, const ScMarkData& rMark, bool bBroadcast = true );
void ClearSelectionItems( const sal_uInt16* pWhich, const ScMarkData& rMark );
diff --git a/sc/source/core/data/attarray.cxx b/sc/source/core/data/attarray.cxx
index 67d0ac67b088..7124e78be37e 100644
--- a/sc/source/core/data/attarray.cxx
+++ b/sc/source/core/data/attarray.cxx
@@ -26,7 +26,7 @@
#include <editeng/editobj.hxx>
#include <editeng/justifyitem.hxx>
#include <osl/diagnose.h>
-#include <svl/poolcach.hxx>
+#include <poolcach.hxx>
#include <sfx2/objsh.hxx>
#include <global.hxx>
@@ -846,7 +846,7 @@ void ScAttrArray::ApplyLineStyleArea( SCROW nStartRow, SCROW nEndRow,
while ((nStart <= nEndRow) && (nPos < mvData.size()));
}
-void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCache* pCache, ScEditDataArray* pDataArray, bool* const pIsChanged )
+void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, ScItemPoolCache* pCache, ScEditDataArray* pDataArray, bool* const pIsChanged )
{
#if DEBUG_SC_TESTATTRARRAY
TestData();
@@ -869,9 +869,9 @@ void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCac
do
{
- const ScPatternAttr* pOldPattern = mvData[nPos].pPattern;
- const ScPatternAttr* pNewPattern = static_cast<const ScPatternAttr*>( &pCache->ApplyTo( *pOldPattern ) );
- if (!SfxPoolItem::areSame(pNewPattern, pOldPattern))
+ const ScPatternAttr& rOldPattern = *mvData[nPos].pPattern;
+ const ScPatternAttr& rNewPattern = pCache->ApplyTo( rOldPattern );
+ if (!SfxPoolItem::areSame(rNewPattern, rOldPattern))
{
SCROW nY1 = nStart;
SCROW nY2 = mvData[nPos].nEndRow;
@@ -884,7 +884,7 @@ void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCac
{
if (nY1 < nStartRow) nY1=nStartRow;
if (nY2 > nEndRow) nY2=nEndRow;
- SetPatternArea( nY1, nY2, pNewPattern, false, pDataArray );
+ SetPatternArea( nY1, nY2, &rNewPattern, false, pDataArray );
Search( nStart, nPos );
}
else
@@ -893,8 +893,8 @@ void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCac
{
// ensure attributing changes text-width of cell
- const SfxItemSet& rNewSet = pNewPattern->GetItemSet();
- const SfxItemSet& rOldSet = pOldPattern->GetItemSet();
+ const SfxItemSet& rNewSet = rNewPattern.GetItemSet();
+ const SfxItemSet& rOldSet = rOldPattern.GetItemSet();
bool bNumFormatChanged;
if ( ScGlobal::CheckWidthInvalidate( bNumFormatChanged,
@@ -907,7 +907,7 @@ void ScAttrArray::ApplyCacheArea( SCROW nStartRow, SCROW nEndRow, SfxItemPoolCac
}
rDocument.GetPool()->DirectRemoveItemFromPool(*mvData[nPos].pPattern);
- mvData[nPos].pPattern = pNewPattern;
+ mvData[nPos].pPattern = &rNewPattern;
if (Concat(nPos))
Search(nStart, nPos);
else
@@ -1237,7 +1237,7 @@ bool ScAttrArray::ApplyFrame( const SvxBoxItem& rBoxItem,
}
else
{
- SfxItemPoolCache aCache( rDocument.GetPool(), &aNewFrame );
+ ScItemPoolCache aCache( rDocument.GetPool(), &aNewFrame );
ApplyCacheArea( nStartRow, nEndRow, &aCache );
return true;
diff --git a/sc/source/core/data/document.cxx b/sc/source/core/data/document.cxx
index 1d253db1537a..060bd85eebbc 100644
--- a/sc/source/core/data/document.cxx
+++ b/sc/source/core/data/document.cxx
@@ -27,7 +27,7 @@
#include <sfx2/objsh.hxx>
#include <sfx2/docfile.hxx>
#include <svl/numformat.hxx>
-#include <svl/poolcach.hxx>
+#include <poolcach.hxx>
#include <svl/zforlist.hxx>
#include <unotools/charclass.hxx>
#include <unotools/transliterationwrapper.hxx>
@@ -5912,7 +5912,7 @@ void ScDocument::ApplySelectionPattern( const ScPatternAttr& rAttr, const ScMark
}
else
{
- SfxItemPoolCache aCache( mxPoolHelper->GetDocPool(), pSet );
+ ScItemPoolCache aCache( mxPoolHelper->GetDocPool(), pSet );
SCTAB nMax = GetTableCount();
for (const auto& rTab : rMark)
{
diff --git a/svl/source/items/poolcach.cxx b/sc/source/core/data/poolcach.cxx
index 957f9a37edb1..d929933d0e96 100644
--- a/svl/source/items/poolcach.cxx
+++ b/sc/source/core/data/poolcach.cxx
@@ -21,10 +21,11 @@
#include <svl/itempool.hxx>
#include <svl/itemset.hxx>
#include <svl/setitem.hxx>
-#include <svl/poolcach.hxx>
+#include <poolcach.hxx>
#include <tools/debug.hxx>
+#include <patattr.hxx>
-SfxItemPoolCache::SfxItemPoolCache( SfxItemPool *pItemPool,
+ScItemPoolCache::ScItemPoolCache( SfxItemPool *pItemPool,
const SfxPoolItem *pPutItem ):
pPool(pItemPool),
pSetToPut( nullptr ),
@@ -34,7 +35,7 @@ SfxItemPoolCache::SfxItemPoolCache( SfxItemPool *pItemPool,
}
-SfxItemPoolCache::SfxItemPoolCache( SfxItemPool *pItemPool,
+ScItemPoolCache::ScItemPoolCache( SfxItemPool *pItemPool,
const SfxItemSet *pPutSet ):
pPool(pItemPool),
pSetToPut( pPutSet ),
@@ -44,7 +45,7 @@ SfxItemPoolCache::SfxItemPoolCache( SfxItemPool *pItemPool,
}
-SfxItemPoolCache::~SfxItemPoolCache()
+ScItemPoolCache::~ScItemPoolCache()
{
for (const SfxItemModifyImpl & rImpl : m_aCache) {
pPool->DirectRemoveItemFromPool( *rImpl.pPoolItem );
@@ -56,7 +57,7 @@ SfxItemPoolCache::~SfxItemPoolCache()
}
-const SfxSetItem& SfxItemPoolCache::ApplyTo( const SfxSetItem &rOrigItem )
+const ScPatternAttr& ScItemPoolCache::ApplyTo( const ScPatternAttr &rOrigItem )
{
DBG_ASSERT( pPool == rOrigItem.GetItemSet().GetPool(), "invalid Pool" );
DBG_ASSERT( IsDefaultItem( &rOrigItem ) || IsPooledItem( &rOrigItem ),
@@ -79,7 +80,7 @@ const SfxSetItem& SfxItemPoolCache::ApplyTo( const SfxSetItem &rOrigItem )
}
// Insert the new attributes in a new Set
- std::unique_ptr<SfxSetItem> pNewItem(rOrigItem.Clone());
+ std::unique_ptr<ScPatternAttr> pNewItem(rOrigItem.Clone());
if ( pItemToPut )
{
pNewItem->GetItemSet().Put( *pItemToPut );
@@ -88,7 +89,7 @@ const SfxSetItem& SfxItemPoolCache::ApplyTo( const SfxSetItem &rOrigItem )
}
else
pNewItem->GetItemSet().Put( *pSetToPut );
- const SfxSetItem* pNewPoolItem = &pPool->DirectPutItemInPool( std::move(pNewItem) );
+ const ScPatternAttr* pNewPoolItem = &pPool->DirectPutItemInPool( std::move(pNewItem) );
// Adapt refcount; one each for the cache
pNewPoolItem->AddRef( !areSfxPoolItemPtrsEqual(pNewPoolItem, &rOrigItem) ? 2 : 1 );
@@ -97,7 +98,7 @@ const SfxSetItem& SfxItemPoolCache::ApplyTo( const SfxSetItem &rOrigItem )
// Add the transformation to the cache
SfxItemModifyImpl aModify;
aModify.pOrigItem = &rOrigItem;
- aModify.pPoolItem = const_cast<SfxSetItem*>(pNewPoolItem);
+ aModify.pPoolItem = const_cast<ScPatternAttr*>(pNewPoolItem);
m_aCache.push_back( aModify );
DBG_ASSERT( !pItemToPut ||
diff --git a/sc/source/core/data/table2.cxx b/sc/source/core/data/table2.cxx
index 52234b29b232..89ded6428766 100644
--- a/sc/source/core/data/table2.cxx
+++ b/sc/source/core/data/table2.cxx
@@ -60,7 +60,7 @@
#include <o3tl/unit_conversion.hxx>
#include <osl/diagnose.h>
#include <sal/log.hxx>
-#include <svl/poolcach.hxx>
+#include <poolcach.hxx>
#include <unotools/charclass.hxx>
#include <math.h>
@@ -479,7 +479,7 @@ void ScTable::DeleteSelection( InsertDeleteFlags nDelFlag, const ScMarkData& rMa
ScDocumentPool* pPool = rDocument.GetPool();
SfxItemSetFixed<ATTR_PATTERN_START, ATTR_PATTERN_END> aSet( *pPool );
aSet.Put( ScProtectionAttr( false ) );
- SfxItemPoolCache aCache( pPool, &aSet );
+ ScItemPoolCache aCache( pPool, &aSet );
ApplySelectionCache( &aCache, rMark );
}
@@ -3219,7 +3219,7 @@ void ScTable::ApplyAttr( SCCOL nCol, SCROW nRow, const SfxPoolItem& rAttr )
CreateColumnIfNotExists(nCol).ApplyAttr( nRow, rAttr );
}
-void ScTable::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark,
+void ScTable::ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark,
ScEditDataArray* pDataArray, bool* const pIsChanged )
{
if(!rMark.GetTableSelect(nTab))
diff --git a/solenv/clang-format/excludelist b/solenv/clang-format/excludelist
index 1c63e0c67b5d..34bef2dcfe2d 100644
--- a/solenv/clang-format/excludelist
+++ b/solenv/clang-format/excludelist
@@ -5655,7 +5655,6 @@ include/svl/nfsymbol.hxx
include/svl/numuno.hxx
include/svl/ownlist.hxx
include/svl/pickerhistoryaccess.hxx
-include/svl/poolcach.hxx
include/svl/poolitem.hxx
include/svl/ptitem.hxx
include/svl/rectitem.hxx
@@ -7905,6 +7904,7 @@ sc/inc/pagepar.hxx
sc/inc/paramisc.hxx
sc/inc/patattr.hxx
sc/inc/pivot.hxx
+sc/inc/poolcach.hxx
sc/inc/postit.hxx
sc/inc/printopt.hxx
sc/inc/prnsave.hxx
@@ -8093,6 +8093,7 @@ sc/source/core/data/olinetab.cxx
sc/source/core/data/pagepar.cxx
sc/source/core/data/patattr.cxx
sc/source/core/data/pivot2.cxx
+sc/source/core/data/poolcach.cxx
sc/source/core/data/poolhelp.cxx
sc/source/core/data/postit.cxx
sc/source/core/data/queryiter.cxx
@@ -11062,7 +11063,6 @@ svl/source/items/itemset.cxx
svl/source/items/lckbitem.cxx
svl/source/items/legacyitem.cxx
svl/source/items/macitem.cxx
-svl/source/items/poolcach.cxx
svl/source/items/ptitem.cxx
svl/source/items/rectitem.cxx
svl/source/items/rngitem.cxx
diff --git a/svl/Library_svl.mk b/svl/Library_svl.mk
index 56923d712ced..04abb8c6cf3a 100644
--- a/svl/Library_svl.mk
+++ b/svl/Library_svl.mk
@@ -132,7 +132,6 @@ $(eval $(call gb_Library_add_exception_objects,svl,\
svl/source/items/lckbitem \
svl/source/items/legacyitem \
svl/source/items/macitem \
- svl/source/items/poolcach \
svl/source/items/poolitem \
svl/source/items/ptitem \
svl/source/items/rectitem \
diff --git a/sc/source/core/data/column.cxx b/sc/source/core/data/column.cxx
index 26fbd5cbfa5c..9052c6d098b6 100644
--- a/sc/source/core/data/column.cxx
+++ b/sc/source/core/data/column.cxx
@@ -47,7 +47,7 @@
#include <bcaslot.hxx>
#include <svl/numformat.hxx>
-#include <svl/poolcach.hxx>
+#include <poolcach.hxx>
#include <svl/zforlist.hxx>
#include <svl/sharedstringpool.hxx>
#include <editeng/fieldupdater.hxx>
@@ -375,13 +375,13 @@ sal_uInt32 ScColumnData::GetNumberFormat( SCROW nStartRow, SCROW nEndRow ) const
return nFormat;
}
-SCROW ScColumn::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray,
+SCROW ScColumn::ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray,
bool* const pIsChanged )
{
return ScColumnData::ApplySelectionCache( pCache, rMark, pDataArray, pIsChanged, nCol );
}
-SCROW ScColumnData::ApplySelectionCache( SfxItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray,
+SCROW ScColumnData::ApplySelectionCache( ScItemPoolCache* pCache, const ScMarkData& rMark, ScEditDataArray* pDataArray,
bool* const pIsChanged, SCCOL nCol )
{
SCROW nTop = 0;
@@ -468,23 +468,23 @@ void ScColumn::DeleteSelection( InsertDeleteFlags nDelFlag, const ScMarkData& rM
void ScColumn::ApplyPattern( SCROW nRow, const ScPatternAttr& rPatAttr )
{
const SfxItemSet* pSet = &rPatAttr.GetItemSet();
- SfxItemPoolCache aCache( GetDoc().GetPool(), pSet );
+ ScItemPoolCache aCache( GetDoc().GetPool(), pSet );
const ScPatternAttr* pPattern = pAttrArray->GetPattern( nRow );
// true = keep old content
- const ScPatternAttr* pNewPattern = static_cast<const ScPatternAttr*>( &aCache.ApplyTo( *pPattern ) );
+ const ScPatternAttr& rNewPattern = aCache.ApplyTo( *pPattern );
- if (!SfxPoolItem::areSame(pNewPattern, pPattern))
- pAttrArray->SetPattern( nRow, pNewPattern );
+ if (!SfxPoolItem::areSame(rNewPattern, *pPattern))
+ pAttrArray->SetPattern( nRow, &rNewPattern );
}
void ScColumnData::ApplyPatternArea( SCROW nStartRow, SCROW nEndRow, const ScPatternAttr& rPatAttr,
ScEditDataArray* pDataArray, bool* const pIsChanged )
{
const SfxItemSet* pSet = &rPatAttr.GetItemSet();
- SfxItemPoolCache aCache( GetDoc().GetPool(), pSet );
+ ScItemPoolCache aCache( GetDoc().GetPool(), pSet );
pAttrArray->ApplyCacheArea( nStartRow, nEndRow, &aCache, pDataArray, pIsChanged );
}
@@ -492,7 +492,7 @@ void ScColumn::ApplyPatternIfNumberformatIncompatible( const ScRange& rRange,
const ScPatternAttr& rPattern, SvNumFormatType nNewType )
{
const SfxItemSet* pSet = &rPattern.GetItemSet();
- SfxItemPoolCache aCache( GetDoc().GetPool(), pSet );
+ ScItemPoolCache aCache( GetDoc().GetPool(), pSet );
SvNumberFormatter* pFormatter = GetDoc().GetFormatTable();
SCROW nEndRow = rRange.aEnd.Row();
for ( SCROW nRow = rRange.aStart.Row(); nRow <= nEndRow; nRow++ )
@@ -621,7 +621,7 @@ const ScStyleSheet* ScColumn::GetAreaStyle( bool& rFound, SCROW nRow1, SCROW nRo
void ScColumn::ApplyAttr( SCROW nRow, const SfxPoolItem& rAttr )
{
// in order to only create a new SetItem, we don't need SfxItemPoolCache.
//TODO: Warning: SfxItemPoolCache seems to create too many Refs for the new SetItem ??
ScDocumentPool* pDocPool = GetDoc().GetPool();
@@ -621,7 +621,7 @@ const ScStyleSheet* ScColumn::GetAreaStyle( bool& rFound, SCROW nRow1, SCROW nRo
{
// in order to only create a new SetItem, we don't need SfxItemPoolCache.
- //TODO: Warning: SfxItemPoolCache seems to create too many Refs for the new SetItem ??
+ //TODO: Warning: ScItemPoolCache seems to create too many Refs for the new SetItem ??
ScDocumentPool* pDocPool = GetDoc().GetPool();